<?php
/*
 * Plugin Name:       Woo Category Dropdown (EasyToolsWP)
 * Description:       Adds a dropdown with subcategories on category pages and sibling categories on subcategory pages.
 * Version:           1.0.1
 * Requires at least: 6.6
 * Author:            EasyToolsWP.com
 * Requires Plugins:  woocommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

add_action( 'woocommerce_before_shop_loop', 'add_category_dropdown', 25 );

function add_category_dropdown() {
    if ( ! is_product_category() ) {
        return;
    }

    $queried_object = get_queried_object();

    if ( $queried_object && is_a( $queried_object, 'WP_Term' ) ) {
        $current_cat_id = $queried_object->term_id;
        $parent_cat_id = $queried_object->parent;

        if ( $parent_cat_id == 0 ) {
            // We're on a top-level category
            $subcategories = get_terms( array(
                'taxonomy'   => 'product_cat',
                'child_of'   => $current_cat_id,
                'hide_empty' => false,
            ));
        } else {
            // We're on a subcategory
            $subcategories = get_terms( array(
                'taxonomy'   => 'product_cat',
                'child_of'   => $parent_cat_id,
                'hide_empty' => false,
            ));
        }

        if ( ! empty( $subcategories ) && ! is_wp_error( $subcategories ) ) {
            // Wrapping the dropdown in a div for inline display
            echo '<div style="display: inline-block; margin-left: 10px;">'; // Adjust margin as needed
            echo '<select style="display: inline-block; width: 280px; padding: 10px; background-color: #fff; border: 2px solid #007cba; border-radius: 5px; font-size: 16px;" id="subcategory-dropdown" onchange="location = this.value;">';
            echo '<option value="">' . __( 'Select a category', 'woocommerce' ) . '</option>';

            foreach ( $subcategories as $subcategory ) {
                $selected = ( $subcategory->term_id == $current_cat_id ) ? ' selected="selected"' : '';
                echo '<option value="' . esc_url( get_term_link( $subcategory ) ) . '"' . $selected . '>' . esc_html( $subcategory->name ) . '</option>';
            }

            echo '</select>';
            echo '</div>'; // Closing the wrapper div
        }
    }
}

?>
